# coding=utf-8
from __future__ import absolute_import

import octoprint.plugin

class ChambertempPlugin(octoprint.plugin.StartupPlugin,
                        octoprint.plugin.AssetPlugin,
                        octoprint.plugin.TemplatePlugin,
                        octoprint.plugin.SettingsPlugin):

    def on_after_startup(self):
        self._logger.info("ChamberTemp is up, MQTT subscriber: %s" % self._settings.get(["subPath"]))
        helpers = self._plugin_manager.get_helpers("mqtt", "mqtt_publish", "mqtt_subscribe", "mqtt_unsubscribe")
	if helpers:
            if "mqtt_publish" in helpers:
		self.mqtt_publish = helpers["mqtt_publish"]
            if "mqtt_subscribe" in helpers:
                self.mqtt_subscribe = helpers["mqtt_subscribe"]
            if "mqtt_unsubscribe" in helpers:
                self.mqtt_unsubscribe = helpers["mqtt_unsubscribe"]

            self.mqtt_subscribe(self._settings.get(["subPath"]), self._on_mqtt_subscription)
             

    def __init__(self):
	self.mqtt_publish = lambda *args, **kwargs: None
	self.mqtt_subscribe = lambda *args, **kwargs: None
	self.mqtt_unsubscribe = lambda *args, **kwargs: None

    def _on_mqtt_subscription(self, topic, message, retained=None, qos=None, *args, **kwargs):
        self._plugin_manager.send_plugin_message(self._identifier,dict(chatemp=message))

	##~~ SettingsPlugin mixin

    def get_settings_defaults(self):
        return dict(subPath="/printer/chamber")

    def get_template_configs(self):
        return [
            dict(type="navbar", custom_bindings=False),
            dict(type="settings", custom_bindings=False)
        ]

	##~~ AssetPlugin mixin

    def get_assets(self):
            # Define your plugin's asset files to automatically include in the
            # core UI here.
        return dict(
            js=["js/chambertemp.js"],
            css=["css/chambertemp.css"],
            less=["less/chambertemp.less"]
        )

	##~~ Softwareupdate hook

    def get_update_information(self):
            # Define the configuration for your plugin to use with the Software Update
            # Plugin here. See https://github.com/foosel/OctoPrint/wiki/Plugin:-Software-Update
            # for details.
        return dict(
            chambertemp=dict(
                displayName="Chambertemp Plugin",
                displayVersion=self._plugin_version,

                # version check: github repository
                type="github_release",
                user="linuxpaul",
                repo="OctoPrint-Chambertemp",
                current=self._plugin_version,

                # update method: pip
                pip="https://github.com/linuxpaul/OctoPrint-Chambertemp/archive/{target_version}.zip"
            )
        )

# If you want your plugin to be registered within OctoPrint under a different name than what you defined in setup.py
# ("OctoPrint-PluginSkeleton"), you may define that here. Same goes for the other metadata derived from setup.py that
# can be overwritten via __plugin_xyz__ control properties. See the documentation for that.
__plugin_name__ = "Chambertemp Plugin"

def __plugin_load__():
    global __plugin_implementation__
    __plugin_implementation__ = ChambertempPlugin()
    global __plugin_hooks__
    __plugin_hooks__ = {
        "octoprint.plugin.softwareupdate.check_config": __plugin_implementation__.get_update_information
    }

